@@ -12,8 +12,8 @@ def clear(dir='.'):
             if i=='__pycache__':
                 remove_dir(dir+i)
             else:
-                clear_cache(dir+i)
+                clear(dir+i)
 
 
 if __name__=='__main__':
-    clear_cache('.')
\ No newline at end of file
+    clear('.')
\ No newline at end of file
